@@ -57,7 +57,27 @@ def open_op(mat, iterations=1, kernel_size=3):
     mat_dilated = cv.dilate(mat_dilated.astype(np.uint8), kernel, iterations=iterations)
     return mat_dilated > 0
 
+def get_gravity_center(mask):
+    num = np.sum(np.abs(mask))
+    gra_cen_x = np.sum(np.abs(mask) * np.arange(mask.shape[1]) / max(1, num))
+    gra_cen_y = np.sum(np.abs(mask).T * np.arange(mask.shape[0]) / max(1, num))
+    return gra_cen_x, gra_cen_y
 
+def contour_center(mask):
+    contours, hierarchy = cv2.findContours((mask != 0).astype('uint8'), 2, 1)
+    points = np.vstack(contours).squeeze()
+    center_x, center_y = np.mean(points, axis=0)
+    return center_x, center_y
+
+def ring_degree(mask):
+    center_x, center_y = contour_center(mask)
+    Ys, Xs = np.nonzero(mask)
+    dis = ((Ys - center_y) ** 2 + (Xs - center_x) ** 2) ** 0.5
+    max_radius = np.percentile(dis, 98)
+    min_radius = np.percentile(dis, 2)
+    ring_area = np.pi * (max_radius ** 2 - min_radius ** 2)
+    degree = len(Ys) / max(1, ring_area)
+    return degree
 
 def show_hist(img):
     rows, cols = img.shape
