@@ -1486,6 +1486,8 @@ def remove_file(path):
         if OS_isfile(path) or islink(path):
             os.remove(path)
 
+def get_path_stem(path):
+    return Path(path).stem
 
 def remove_dir(path):
     """remove a dir or a symlink"""
